@@ -660,40 +660,3 @@ c     dlamch('o') returns max double precision
 
       return
       end
-
-c-----------------------------------------------------------------------
-
-      subroutine nwstrot(s)
-      character*(*) s
-
-c     Intermediate output routine
-c     trim string and pass it with trimmed length
-c     to  C routine defined in <nwout.c>
-
-      integer slen
-      slen = len_trim(s)
-      call nwstrot0(s,slen)
-
-      return
-      end
-
-c-----------------------------------------------------------------------
-
-      subroutine nwckot(i,j,aij,wi)
-      integer i,j
-      double precision aij,wi
-
-c     output error message for check analytic jacobian
-
-      character*80 s
-
-      write(s,900) i,j
-      call nwstrot(s)
-      write(s,901) aij,wi
-      call nwstrot(s)
-
- 900  format('Chkjac  possible error in jacobian(',i4,',',i4,')')
- 901  format('       ', d20.13, ' Estimated = ', d20.13)
-
-      return
-      end
